@@ -282,7 +282,7 @@ class StringParser {
 			StringParser_Node::destroyNode ($this->_root);
 		}
 		unset ($this->_root);
-		$this->_root =& new StringParser_Node_Root ();
+		$this->_root = new StringParser_Node_Root ();
 		$this->_stack[0] =& $this->_root;
 		
 		$this->_parserInit ();
@@ -979,7 +979,7 @@ class StringParser_Node {
 	function appendToLastTextChild ($text) {
 		$ccount = count ($this->_children);
 		if ($ccount == 0 || $this->_children[$ccount-1]->_type != STRINGPARSER_NODE_TEXT) {
-			$ntextnode =& new StringParser_Node_Text ($text);
+			$ntextnode = new StringParser_Node_Text ($text);
 			return $this->appendChild ($ntextnode);
 		} else {
 			$this->_children[$ccount-1]->appendText ($text);
@@ -1541,4 +1541,4 @@ class StringParser_Node_Text extends StringParser_Node {
 	}
 }
 
-?>
\ No newline at end of file
+?>
