@@ -1,7 +1,7 @@
 /****************************
  * Slider theme for Gallery2
  * @author Alan Harder <alan.harder@sun.com>
- * $Revision: 15342 $
+ * $Revision: 16920 $
  */
 
 //Class app
@@ -165,7 +165,7 @@ function image_show(i) {
   image_index = i;
   ui_sethtml('title', document.getElementById('title_'+image_index).innerHTML);
   image_setsize();
-  if (options_on) options_setsize();
+  if (options_on) { options_setsize(); options_setItemLinks(i); }
   if (image_map && app_is_ie) {
     document.getElementById('prevArrow').style.visibility = 'hidden';
     document.getElementById('nextArrow').style.visibility = 'hidden';
